class Filter {

    constructor (filterChangedCallBack) {
        this.filterChangedCallBack = filterChangedCallBack;  
        this.properties = {};
        
        const container = document.createElement("div");
        container.id = "filterContent";
        document.getElementById('filterContainer').appendChild(container);
        this.container = container;
    }

    addProperty(name, label, type) {
        this.properties[name] = {
            label: label,
            type: type,
            values: new Set()
        };

        let div = document.createElement("div");
        div.id = name;
        let myId = "propcolor-" + name;
        div.innerHTML = "<h3>" + label + '<input type="checkbox" id="' + myId + '" name="' + name + '"></h3>';
        this.container.appendChild(div);
        document.getElementById(myId).onchange = () => { this.selectionChanged() };
    }

    addValue (propName, value) {
        if(!this.properties[propName].values.has(value)) {
            this.properties[propName].values.add(value);
                
            let option = document.createElement("div");
            let input = document.createElement("input");
            input.type = "checkbox";
            input.name = value;
            const myId = propName + "-" + value;
            input.id = myId;
            
            option.appendChild(input);
            option.innerHTML = option.innerHTML + " " + value;
            document.getElementById(propName).appendChild(option);
            document.getElementById(myId).onchange = () => { this.selectionChanged() };
        }
    }

    selectionChanged() {
        let propNames = Object.getOwnPropertyNames(this.properties);
        let filterObj = {};
        filterObj.filters = [];
        filterObj.colorSplitProps = [];
        filterObj.colorSplits = [];

        // On which properties do we want color separation? 
        for (let i = 0; i < propNames.length; i++) {
            let propName = propNames[i];
            let colorSplit = false;
            if (document.getElementById(propName).checked) {
                let propName = propNames[i];
                let property = this.properties[propName];
                filterObj.colorSplitProps.push(propName);
            }
        }

        for (let i = 0; i < propNames.length; i++) {
            
            let propName = propNames[i];

            let colorSplit = false;
            if (document.getElementById("propcolor-" + propName).checked) {
                colorSplit = true;
            }

            let property = this.properties[propName];
            let filter = { 
                name: propName,
                filtered: false,
                colorSplit: colorSplit,
                values: [],
                colors: []
            };
            
            for (let item of property.values) {
                if (document.getElementById(propName + "-" + item).checked) {
                    filter.values.push(item);
                    filter.filtered = true;
                }
            }

            // Bij colorsplit: indien niks geselecteerd, filter op alles 
            if(!filter.filtered && filter.colorSplit) {
                for (let item of property.values) {
                    filter.values.push(item);
                    filter.filtered = true;
                }   
            }

            filterObj.filters.push(filter);

            if(colorSplit) {
                let hueFraction = 360 / filter.values.length;
                console.log(hueFraction);
                for (let i = 0; i < filter.values.length; i++) {
                    let color = this._HSLToHEX(hueFraction * (i), 95, 50);
                    filter.colors.push(color);
                }
            }
        }

        this.filterChangedCallBack(filterObj);

    }

    _HSLToHEX(h,s,l) { // Credit: https://css-tricks.com/converting-color-spaces-in-javascript/

        console.log(h, s, l);
        
            s /= 100;
            l /= 100;
          
            let c = (1 - Math.abs(2 * l - 1)) * s,
                x = c * (1 - Math.abs((h / 60) % 2 - 1)),
                m = l - c/2,
                r = 0,
                g = 0,
                b = 0;
          
            if (0 <= h && h < 60) {
              r = c; g = x; b = 0;
            } else if (60 <= h && h < 120) {
              r = x; g = c; b = 0;
            } else if (120 <= h && h < 180) {
              r = 0; g = c; b = x;
            } else if (180 <= h && h < 240) {
              r = 0; g = x; b = c;
            } else if (240 <= h && h < 300) {
              r = x; g = 0; b = c;
            } else if (300 <= h && h < 360) {
              r = c; g = 0; b = x;
            }
            // Having obtained RGB, convert channels to hex
            r = Math.round((r + m) * 255).toString(16);
            g = Math.round((g + m) * 255).toString(16);
            b = Math.round((b + m) * 255).toString(16);
          
            // Prepend 0s, if necessary
            if (r.length == 1)
              r = "0" + r;
            if (g.length == 1)
              g = "0" + g;
            if (b.length == 1)
              b = "0" + b;
          
            return r + g + b;
          }
      

}

export { Filter };