import { SoftpakConnector } from "./softpakConnector.js";

class Implementation {

  constructor() {
    this.t3d = null;
    this.softpakConnector = null;
  }

  init(t3d) {
    this.t3d = t3d;

    let config = this.getConfig();

    this.softpakConnector = new SoftpakConnector(t3d, config.baseUrl, config.companycode, config.depotcode);
      this.softpakConnector.login().then(() => {

      /* this.softpakConnector.getData('locations').then(locationData => {
      }); */

      for (let i = 0; i < config.groundLabelPlanes.length; i++) { 
        let groundLabelPlane = config.groundLabelPlanes[i];
        this.t3d.equipmentController.addGroundLabelPlane(groundLabelPlane);
      }

      for (let i = 0; i < config.groundPlanes.length; i++) { 
        let groundPlane = config.groundPlanes[i];
        this.t3d.equipmentController.addGroundPlane(groundPlane);
      }

      for (let i = 0; i < config.locations.length; i++) {
        let location = config.locations[i];
        if (location.type === 'heap') {
          let heapLoc = this.t3d.locationController.addHeapLocation( location.x, location.y, location.depth, location.width, 320, location.rotation, false, location.locationcode, 0x3333aa); 
          heapLoc.label = location.locationcode;
          heapLoc.capacity = location.capacity;
        }
      }
      
      console.log(config.statics);
      for (let i = 0; i < config.statics.length; i++) { 
        let staticObj = config.statics[i];
        console.log(staticObj);
        this.t3d.equipmentController.addGround(staticObj);
      }

      this.softpakConnector.getData('containers').then(data => {
        this.softpakConnector.processContainers(data);
        loadVisualScript('Customer');
      });
      
      if (config.interval) {
        window.setInterval(() => {
          this.softpakConnector.getData('containers').then(data => {
            this.softpakConnector.processContainers(data);
          });
        }, config.interval);
      }
            
      if (config.logo) {
       // this.t3d.view.viewLogo.addLogo('assets/logo/' + config.logo.filename, config.logo.x, config.logo.y, 20);
      }
      
    });

  }

  changeLocation(containers, location, mode) {
    let containerIds = [];
    for (let i = 0; i < containers.length; i++ ) {
      let container = containers[i];
      containerIds.push(container.properties.extId);
      console.log(container);
    }
    let containerIdList = containerIds.join(',');
    let result = this.softpakConnector.changeLocation(containerIdList, location.locationCode, mode);
    let message = '';
    if (result.response.plOk === true) {
      message = "Relocate order created";
    } else {
      message = "Error!\n" + result.response.pcErrorMessage;
    }
    alert(message);

  }

  getConfig() {
    var request = new XMLHttpRequest();
    request.open('GET', 'implementation/kramer.json', false);  // `false` makes the request synchronous
    request.send(null);

    if (request.status === 200) {
      return JSON.parse(request.responseText);
    }
  }


}


var visObj = [
  {
    name: 'Customer',
    code: "let XCL = 0xC41616;\nlet EIM = 0xe8bd6d;\nlet SAM = 0xb5744c;\nlet EUC = 0x16C416;\nlet CMA = 0x1616C4;\nlet BGF = 0x329da8\n\n\n  container.opacity = 1;\n  if (container.properties.customer === 'XCL') {container.color = XCL}; \n  if (container.properties.customer === 'EIM') {container.color = EIM}; \n  if (container.properties.customer === 'SAM') {container.color = SAM}; \n  if (container.properties.customer === 'EUC') {container.color = EUC}; \n  if (container.properties.customer === 'CMA') {container.color = CMA}; \n  if (container.properties.customer === 'BGF') {container.color = BGF};\nmyT3d.legend.add('#C41616', 'XCL'); \nmyT3d.legend.add('#e8bd6d', 'EIM'); \nmyT3d.legend.add('#b5744c', 'SAM'); \nmyT3d.legend.add('#16c416', 'EUC'); \nmyT3d.legend.add('#1616C4', 'CMA'); \nmyT3d.legend.add('#329da8', 'BGF');"
  },
  {
    name: 'IMDG',
    code: "if (container.properties.dangerousGoods === 'YES') {\n  container.color = 0xff0000;\n  container.opacity = 1;\n  container.wireframe = false;\n} else {\n  container.color = 0x0000ff;\n  container.opacity = 0.45;}"
  }
]


export { Implementation, visObj }