import { SoftpakConnector } from "./softpakConnector.js";

class Implementation {

  constructor() {
    this.t3d = null;
    this.softpakConnector = null;
  }

  init(t3d) {
    this.t3d = t3d;
    /* Connector */
    let baseUrl = "https://vpas.softpak.nl:8814/DpApp";
    let companycode = "row"
    let depotcode = '10';
    this.softpakConnector = new SoftpakConnector(t3d, baseUrl, companycode, depotcode);
    this.softpakConnector.stackCodes = "1A,1C,1E,1G,1I,1K,1M,1O,1B,1D,1F,1H,1J,1L,1N,1P,2A,2B,2C,2D,2E,2F,2G,2H,2I,2J,2K,2L,2M,SC,SD";
    this.softpakConnector.login().then(() => {
       
      this.softpakConnector.getData('locations').then(locationData => {
        this.locations = locationData.response.dsStacklocation.dsLocation.tt_stacklocation || [];
        
        //t3d.equipmentController.addGround('cct', 4620, 8358, 3400, -90, 17000, 16000, 500);
        let iBayGrid = 114;
        let stacks, x;

        // Stacks 
        stacks = ['1A', '1C', '1E', '1G', '1I', '1K', '1M', '1O'];
        let yAnchor = 0;

        x = 0;
        for (let istacks = 0; istacks < stacks.length; istacks++) {
          x = x + 1500;
          let extraLabel;
          if (stacks[istacks] === '1G') { extraLabel = '        Reefer points';}
          this._createLocations(x, yAnchor, stacks[istacks], 1, true, extraLabel);
        }

        stacks = ['1B', '1D', '1F', '1H', '1J', '1L', '1N', '1P'];

        x = 550;
        for (let istacks = 0; istacks < stacks.length; istacks++) {
          x = x + 1500;
          this._createLocations(x, yAnchor, stacks[istacks], -1, true);
        }

        // Straddle carrier lanes 
        stacks = ['2A', '2B', '2C','2D','2E','2F','2G','2H','2I','2J','2K','2L','2M'];

        x = 8000;
        yAnchor = -6000;
        for (let istacks = 0; istacks < stacks.length; istacks++) {
          x = x + 160;
          let Baylabels = false;
          let extraLabel
          if (stacks[istacks] === '2A') { Baylabels = true;}
          if (stacks[istacks] === '2G') { extraLabel = 'Straddle carrier lanes';}
          this._createLocations(x, yAnchor, stacks[istacks], 1, Baylabels, extraLabel);
        }


        // RTG Stacks
        stacks = ['SC', 'SD'];

        x = 2000;
        yAnchor = 500;
        for (let istacks = 0; istacks < stacks.length; istacks++) {
          yAnchor = yAnchor + 1200;
          this._createLocations2(x, yAnchor, stacks[istacks], 1, true, true, 90);
        }

        let groundPlane = {x: 2500, y: 3800, rotation: 0, labels: [{text: 'RTG stacks', x: 30, y: 30}]};
        this.t3d.equipmentController.addGroundLabelPlane(groundPlane);

        /* Strip/stuf */
        //x = 550;
        //yAnchor = 2000;
        //this._createStripStufLocations(x, yAnchor, stacks[istacks], -1);

        //t3d.equipmentController.addZone();

        this.softpakConnector.getData('containers').then(data => {
          this.softpakConnector.processContainers(data);
          loadVisualScript('Customer');
        });
        
        window.setInterval(() => {
          this.softpakConnector.getData('containers').then(data => {
            this.softpakConnector.processContainers(data);
          });
        }, 10000);

       
      });
      
      this.t3d.view.viewLogo.addLogo('assets/logo/boxvision2.svg', 3000, -6000, 15);

    });

  }

  _createLocations(x, y, stackcode, modifier, baylabels, extraLabel) {
  
    let iBayGrid = 114;
    let baynrs = [];
            
    let groundPlane = {x: x + 4 , y: y + 200, rotation: 90, labels: [{text: stackcode.toString(), x: 30, y: 30}]};
    this.t3d.equipmentController.addGroundLabelPlane(groundPlane);
    if(extraLabel) {
      groundPlane = {x: x, y: y + 400, rotation: 0, labels: [{text: extraLabel, x: 30, y: 30}]};
      this.t3d.equipmentController.addGroundLabelPlane(groundPlane);
    }

    for (let i = 0; i < this.locations.length; i++) {
      let location = this.locations[i];
      
      if(location.stackcode === stackcode) {

        let hidden = true;

        let size = 420;
        if (location.baynr % 2 !== 0) {
          size = 210;
        }
        
        if(location.stacklocationtype === 'BRT') {
          let found = false;
          for(let ib = 0; ib < baynrs.length; ib++) {
            if(baynrs[ib] === location.baynr) { found = true}
          }
          if (found === false) {
            baynrs.push(location.baynr);
          }
          
          if (location.baynr % 2 !== 0) {
            hidden = false;
          }

          let color = 0x71eef4;
          if (location.ind_inactive === true ) {
            color = 0xaaaaaa;
          } else if (location.ind_reeferpoint) {
            color = 0x3655d1;
          }
          let sl = this.t3d.locationController.addStackLocation( x + ((location.rownr - 1) * (100 * modifier)), y - (location.baynr * iBayGrid), (location.tiernr - 1) * 80, "RMG", 0, hidden, location.stacklocation, size, color);      
        }
        else if (location.stacklocationtype === 'BAY') {
          let bayx = x + (105 * modifier);
          let sl = this.t3d.locationController.addHeapLocation( bayx, y - (location.baynr * iBayGrid), 300, size, 320, 0, hidden, location.stacklocation,  0xaaaaaa); 
        }
      }
      
    }

    /* Bay labels */
    if(baylabels) {
      groundPlane = {x: x - (100 * modifier), y: y, rotation: 90, labels: []};
      for(let ib = 0; ib < baynrs.length; ib++) {
        let baynr = baynrs[ib];
        if( baynr % 2 !== 0) {
          let label = {text: baynr.toString(), x: (ib + 1) * iBayGrid, y: 30 };
          groundPlane.labels.push(label);
        }
      }
      this.t3d.equipmentController.addGroundLabelPlane(groundPlane);
    }

  }

  _createLocations2(x, y, stackcode, modifier, baylabels) {
  
    let iBayGrid = 114;
    let baynrs = [];
            
    let groundPlane = {x: x - 200, y: y + 200, rotation: 90, labels: [{text: stackcode.toString(), x: 30, y: 30}]};
    this.t3d.equipmentController.addGroundLabelPlane(groundPlane);

    for (let i = 0; i < this.locations.length; i++) {
      let location = this.locations[i];
      
      if(location.stackcode === stackcode) {
        
        let found = false;
        for(let ib = 0; ib < baynrs.length; ib++) {
          if(baynrs[ib] === location.baynr) { found = true}
        }
        if (found === false) {
          baynrs.push(location.baynr);
        }

        let size = 420;
        if (location.baynr % 2 !== 0) {
          size = 210;
        }

        let hidden = true;
        if (location.baynr % 2 !== 0) {
          hidden = false;
        }

        let color = 0x71eef4;
        if (location.ind_inactive === true ) {
          color = 0xaaaaaa;
        } else if (location.ind_reeferpoint) {
          color = 0x3655d1;
        }
        let sl = this.t3d.locationController.addStackLocation( x + ((location.baynr - 1) * iBayGrid), y + ((location.rownr - 1) * (100 * modifier)), (location.tiernr - 1) * 80, "RMG", 90, hidden, location.stacklocation, size, color);      
      }
    }
    
    /* Bay labels */
    if(baylabels) {
      groundPlane = {x: x - (100 * modifier), y: y - (200 * modifier) , rotation: 0, labels: []};
      for(let ib = 0; ib < baynrs.length; ib++) {
        let baynr = baynrs[ib];
        if( baynr % 2 !== 0) {
          let label = {text: baynr.toString(), x: (ib + 1) * iBayGrid, y: 30 };
          groundPlane.labels.push(label);
        }
      }
      this.t3d.equipmentController.addGroundLabelPlane(groundPlane);
    }
    
  }

  changeLocation(containers, location, mode) {
    let containerIds = [];
    for (let i = 0; i < containers.length; i++ ) {
      let container = containers[i];
      containerIds.push(container.properties.extId);
      console.log(container);
    }
    let containerIdList = containerIds.join(',');
    let result = this.softpakConnector.changeLocation(containerIdList, location.locationCode, mode);
    let message = '';
    if (result.response.plOk === true) {
      message = "Relocate order created";
    } else {
      message = "Error!\n" + result.response.pcErrorMessage;
    }
    alert(message);

  }

}


var visObj = [
  {
    name: 'Customer',
    code: "let XCL = 0xC41616;\nlet EIM = 0xe8bd6d;\nlet SAM = 0xb5744c;\nlet EUC = 0x16C416;\nlet CMA = 0x1616C4;\nlet BGF = 0x329da8\n\n\n  container.opacity = 1;\n  if (container.properties.customer === 'XCL') {container.color = XCL}; \n  if (container.properties.customer === 'EIM') {container.color = EIM}; \n  if (container.properties.customer === 'SAM') {container.color = SAM}; \n  if (container.properties.customer === 'EUC') {container.color = EUC}; \n  if (container.properties.customer === 'CMA') {container.color = CMA}; \n  if (container.properties.customer === 'BGF') {container.color = BGF};\nmyT3d.legend.add('#C41616', 'XCL'); \nmyT3d.legend.add('#e8bd6d', 'EIM'); \nmyT3d.legend.add('#b5744c', 'SAM'); \nmyT3d.legend.add('#16c416', 'EUC'); \nmyT3d.legend.add('#1616C4', 'CMA'); \nmyT3d.legend.add('#329da8', 'BGF');"
  },
  {
    name: 'IMDG',
    code: "if (container.properties.dangerousGoods === 'YES') {\n  container.color = 0xff0000;\n  container.opacity = 1;\n  container.wireframe = false;\n} else {\n  container.color = 0x0000ff;\n  container.opacity = 0.45;}"
  }
]


export { Implementation, visObj }